@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoEnding.cpp,v 1.13 2009/01/25 05:13:21 bowkenken Exp $
+* $Id: DemoEnding.cpp,v 1.14 2009/06/03 19:25:22 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -283,7 +283,7 @@ bool DemoEnding::draw()
 
 		// ڤؤ
 		wait_time = 0;
-		change_scene( SCENE_N_ENDING_EPILOGUE );
+		change_scene_gui( SCENE_N_ENDING_EPILOGUE );
 	}
 
 	// ԥ
@@ -305,7 +305,7 @@ bool DemoEnding::draw()
 		} else {
 			// ڤؤ
 			wait_time = 0;
-			change_scene( SCENE_N_ENDING_SPACE );
+			change_scene_gui( SCENE_N_ENDING_SPACE );
 		}
 	}
 
@@ -328,7 +328,7 @@ bool DemoEnding::draw()
 		} else {
 			// ڤؤ
 			wait_time = 0;
-			change_scene( SCENE_N_ENDING_STAFF_ROLL );
+			change_scene_gui( SCENE_N_ENDING_STAFF_ROLL );
 		}
 	}
 
