@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiWords.cpp,v 1.7 2009/03/04 11:47:40 bowkenken Exp $
+* $Id: GuiWords.cpp,v 1.8 2009/05/23 15:59:50 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -227,7 +227,7 @@ void GuiWords::draw( const char *str, long w )
 
 	const char *head, *tail;
 	for( head = str; ; head = tail ){
-		static char line[SCREEN_WIDTH * 4 + 1];
+		static char line[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
 
 		tail = get_words_line( head, w );
 		if( tail == NULL )
@@ -253,7 +253,7 @@ void GuiWords::draw( const char *str, long w )
 
 	head = str;
 	for( long i = 0; i < LOOP_MAX_1000; i++ ){
-		static char line[SCREEN_WIDTH * 4 + 1];
+		static char line[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
 
 		tail = get_words_line( head, w );
 		if( tail == NULL )
