@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Pcg.h,v 1.17 2008/10/07 00:41:48 bowkenken Exp $
+* $Id: Pcg.h,v 1.19 2009/02/19 02:11:23 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_H
@@ -63,6 +63,10 @@ private:
 	// եåѥ
 	WSDimage *pImage;
 
+	// ѥΥ
+	long	nWidth;
+	long	nHeight;
+
 public:
 	// ꥹȤμι
 	Pcg *next;
@@ -89,6 +93,9 @@ public:
 		nRate = _100_PERCENT;
 		mjr = FACE_MJR_NULL;
 		mnr = FACE_MNR_NULL;
+
+		nWidth = 0;
+		nHeight = 0;
 	}
 	~Pcg()
 	{
