@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: PcgDunTab.h,v 1.28 2009/01/24 15:01:09 bowkenken Exp $
+* $Id: PcgDunTab.h,v 1.29 2009/05/29 04:53:09 bowkenken Exp $
 ***************************************************************/
 
 #ifndef PCG_DUN_TAB_H
@@ -604,7 +604,7 @@ PcgTab gPcgTabCrsrSub[] = {
 	},
 };
 
-PcgTab gPcgTabSquare[] = {
+PcgTab gPcgTabSquareParty[] = {
 	{
 		MNSTR_KIND_NULL,
 		FACE_MJR_SQUARE, 'N',
@@ -637,6 +637,21 @@ PcgTab gPcgTabSquare[] = {
 	},
 };
 
+PcgTab gPcgTabSquareMbr[] = {
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		100,
+		"anchor/member",
+	},
+	{
+		MNSTR_KIND_NULL,
+		FACE_MJR_NULL, FACE_MNR_NULL,
+		-1,
+		"",
+	},
+};
+
 PcgTab gPcgTabItem[] = {
 	/* Υƥ */
 	{
