@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.103 2009/05/31 07:23:44 bowkenken Exp $
+* $Id: call.cpp,v 1.104 2009/06/03 19:25:12 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -1305,12 +1305,19 @@ bool_t	call_demo_last_boss_check_done( void )
 
 /***************************************************************
 * ˹礻 BGM κ
+* bool_t flg_gui : GUI ƤФ줿?
 ***************************************************************/
 
-void	call_game_music_play_scene( void )
+void	call_game_music_play_scene( bool_t flg_gui )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	if( !flg_gui )
+		gui_begin();
+
 	gMusic.playScene();
+
+	if( !flg_gui )
+		gui_end();
 #endif
 }
 
@@ -1323,7 +1330,11 @@ void	call_game_music_play_scene( void )
 void	call_game_music_play( long kind, long idx )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
 	gMusic.play( (music_kind_t)kind, idx );
+
+	gui_end();
 #endif
 }
 
@@ -1334,19 +1345,28 @@ void	call_game_music_play( long kind, long idx )
 void	call_game_music_replay( void )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
 	gMusic.replay();
+
+	gui_end();
 #endif
 }
 
 /***************************************************************
 * SE κ
 * sound_kind_t kind : SE μ
+* long n : 
 ***************************************************************/
 
 void	call_game_sound_play( long kind, long n )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
 	gSound.play( (sound_kind_t)kind, n );
+
+	gui_end();
 #endif
 }
 
@@ -1357,7 +1377,11 @@ void	call_game_sound_play( long kind, long n )
 void	call_game_sound_stop( void )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
 	gSound.stop();
+
+	gui_end();
 #endif
 }
 
@@ -1369,7 +1393,17 @@ void	call_game_sound_stop( void )
 long	call_game_joystick_get_joy( void )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gJoystick.getJoy();
+	{
+		long	n;
+
+		gui_begin();
+
+		n = gJoystick.getJoy();
+
+		gui_end();
+
+		return n;
+	}
 #endif
 
 	return g_joy_n;
@@ -1383,7 +1417,11 @@ long	call_game_joystick_get_joy( void )
 void	call_game_joystick_sel_joy( long n )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
 	gJoystick.selJoy( n );
+
+	gui_end();
 #endif
 
 	g_joy_n = n;
@@ -1398,7 +1436,17 @@ void	call_game_joystick_sel_joy( long n )
 const char	*call_game_joystick_get_name( long n )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gJoystick.getName( n );
+	{
+		const char	*s;
+
+		gui_begin();
+
+		s = gJoystick.getName( n );
+
+		gui_end();
+
+		return s;
+	}
 #endif
 
 	return NULL;
@@ -1412,7 +1460,17 @@ const char	*call_game_joystick_get_name( long n )
 long	call_game_joystick_get_kind( void )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	return gJoystick.getKind();
+	{
+		long	n;
+
+		gui_begin();
+
+		n = gJoystick.getKind();
+
+		gui_end();
+
+		return n;
+	}
 #endif
 
 	return g_joy_kind;
@@ -1426,7 +1484,11 @@ long	call_game_joystick_get_kind( void )
 void	call_game_joystick_set_kind( long kind )
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gui_begin();
+
 	gJoystick.setKind( (joy_kind_t)kind );
+
+	gui_end();
 #endif
 
 	g_joy_kind = (joy_kind_t)kind;
