@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.116 2008/10/07 00:41:05 bowkenken Exp $
+* $Id: chr.h,v 1.123 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -38,6 +38,7 @@
 #include	"dun.h"
 #include	"fight.h"
 #include	"fx.h"
+#include	"skill.h"
 #include	"misc.h"
 
 #include	"resi.h"
@@ -51,6 +52,8 @@
 * иͤȥ٥
 ***************************************************************/
 
+#define	ABL_SKILL_MAX_N	(ABL_KIND_MAX_N + SKILL_KIND_MAX_N)
+
 /* ٥κǹ */
 #define	ABL_MAX_LEV	9999
 
@@ -65,12 +68,22 @@
 * ̾κʸ
 ***************************************************************/
 
-#define	CHR_NAME_MAX_LEN	80	/* 饯 */
-#define	MBR_NAME_MAX_LEN	16	/* С */
-#define	MNSTR_NAME_MAX_LEN	80	/* 󥹥 */
+/* 饯 */
+#define	CHR_NAME_MAX_LEN	80
+#define	CHR_NAME_MAX_BYTE	(CHR_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
+/* С */
+#define	MBR_NAME_MAX_LEN	16
+#define	MBR_NAME_MAX_BYTE	(MBR_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
+/* 󥹥 */
+#define	MNSTR_NAME_MAX_LEN	CHR_NAME_MAX_LEN
+#define	MNSTR_NAME_MAX_BYTE	CHR_NAME_MAX_BYTE
 
-#define	RACE_STR_MAX_LEN	32	/* ݤ碌ޤ᤿²̾ */
-#define	RACE_NAME_MAX_LEN	16	/* ²̾ */
+/* ݤ碌ޤ᤿²̾ */
+#define	RACE_STR_MAX_LEN	32
+#define	RACE_STR_MAX_BYTE	(RACE_STR_MAX_LEN * CHAR_MAX_LEN_UTF_8)
+/* ²̾ */
+#define	RACE_NAME_MAX_LEN	16
+#define	RACE_NAME_MAX_BYTE	(RACE_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /***************************************************************
 * 饯ǽ
@@ -98,7 +111,7 @@ typedef unsigned long	flg_chr_t;
 #define	FLG_CHR_LIGHT	(1 << 11)	/* äƤ */
 #define	FLG_CHR_DARK	(1 << 12)	/* ǤäƤ */
 #define	FLG_CHR_MAGIC_PROTECT	(1 << 13)	/* ˡ路ʤ */
-#define	FLG_CHR_HYPER	(1 << 13)	/* 緿 */
+#define	FLG_CHR_HYPER	(1 << 14)	/* 緿 */
 #define	FLG_CHR_CAN_DEL	(1 << 20)	/*  */
 #define	FLG_CHR_CAN_DISMISSAL	(1 << 21)	/* Խ */
 
@@ -151,8 +164,13 @@ typedef unsigned long	flg_work_t;
 * 饹
 ***************************************************************/
 
-#define	CLASS_MAX_N	99	/*  */
-#define	CLASS_NAME_MAX_LEN	20	/* ̾κʸ */
+/*  */
+#define	CLASS_MAX_N	99
+
+/* ̾κʸ */
+#define	CLASS_NAME_MAX_LEN	20
+#define	CLASS_NAME_MAX_BYTE	\
+	(CLASS_NAME_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /***************************************************************
 * 󥫡
@@ -170,10 +188,11 @@ typedef unsigned long	flg_work_t;
 
 /* κʸ */
 #define	ACT_MSG_MAX_LEN	64
+#define	ACT_MSG_MAX_BYTE	(ACT_MSG_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /* դĤΨ */
 #define	STAGGER_RATE_CHR_CONFUSION	((rate_t)70)	/*  */
-#define	STAGGER_RATE_CHR_BLIND	((rate_t)80)	/* ܤʤ */
+#define	STAGGER_RATE_CHR_BLIND	((rate_t)30)	/* ܤʤ */
 #define	STAGGER_RATE_CHR_DRUNK	((rate_t)50)	/* äƤ */
 
 /* 󥹥λäƤ륢ƥκ */
@@ -227,7 +246,7 @@ typedef enum {
 typedef struct {
 	main_race_t	main;
 	sub_race_t	sub;
-	char	name[RACE_NAME_MAX_LEN + 1];
+	char	name[RACE_NAME_MAX_BYTE + 1];
 } race_t;
 
 /***************************************************************
@@ -335,8 +354,8 @@ typedef struct {
 
 /* ǽ */
 typedef struct {
-	abl_exp_t	exp[ABL_KIND_MAX_N];
-	abl_lev_t	lev[ABL_KIND_MAX_N];
+	abl_exp_t	exp[ABL_SKILL_MAX_N];
+	abl_lev_t	lev[ABL_SKILL_MAX_N];
 	abl_val_t	hp, mp;
 } abl_t;
 
@@ -397,7 +416,7 @@ typedef struct {
 	rate_t	armor_def, armor_crtcl, armor_ac;
 
 	/* ٥ */
-	long	add_lev[ABL_KIND_MAX_N];
+	long	add_lev[ABL_SKILL_MAX_N];
 	/*  */
 	long	add_resi_n[RESI_KIND_MAX_N];
 	/*  */
@@ -455,12 +474,15 @@ typedef enum {
 typedef struct {
 	/* ̾ */
 	n_msg_t	n_name;
-	char	name[CLASS_NAME_MAX_LEN + 1];
+	char	name[CLASS_NAME_MAX_BYTE + 1];
 
 	/* ǥեȤΥ饹 */
 	class_dflt_t	dflt;
+
 	/* иͤʬ */
 	rate_t	abl_rate[ABL_KIND_MAX_N];
+	/* åȤƤ륹 */
+	skill_kind_t	skill[SKILL_MAX_N];
 } class_t;
 
 /***************************************************************
@@ -526,11 +548,11 @@ typedef struct {
 	long	n, n2;
 
 	/* ɽʸ */
-	char	msg[ACT_MSG_MAX_LEN + 1];
+	char	msg[ACT_MSG_MAX_BYTE + 1];
 
 	act_kind_t	dflt_kind_mnstr;
 	/* ɽʸ */
-	char	dflt_msg_mnstr[ACT_MSG_MAX_LEN + 1];
+	char	dflt_msg_mnstr[ACT_MSG_MAX_BYTE + 1];
 } act_t;
 
 /***************************************************************
@@ -603,7 +625,7 @@ typedef enum {
 * 饯緿
 ***************************************************************/
 
-/* NULL  PERFECT ʳϽ֤¤ѤƤOK */
+/* NULL, NORMAL, PERFECT ʳϽ֤¤ѤƤOK */
 
 typedef enum {
 	/* 緿̵ */
@@ -767,7 +789,7 @@ typedef struct chr_t {
 
 	/* μ */
 	chr_kind_t	kind;
-	char	name[CHR_NAME_MAX_LEN + 1];
+	char	name[CHR_NAME_MAX_BYTE + 1];
 
 	/* ԡɻ ID */
 	long	id1, id2;
