@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.31 2009/02/17 00:56:59 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.32 2009/05/28 07:29:09 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
@@ -43,7 +43,26 @@
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
+* 
+* 󥫡ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+* 󥫡 SQUARE_DIR_NORTH ǡ롣
+***************************************************************/
+
+square_dir_t	g_square_dir_trans_tab[] = {
+	SQUARE_DIR_NORTH,
+	SQUARE_DIR_EAST,
+	SQUARE_DIR_SOUTH,
+	SQUARE_DIR_WEST,
+};
+
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+*  Ф˽֤ѹʤͤˡ 
 * 
 * 饯μɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -61,7 +80,7 @@ chr_kind_t	g_chr_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ²ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -81,7 +100,7 @@ main_race_t	g_main_race_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ²ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -105,7 +124,7 @@ sub_race_t	g_sub_race_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ̤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -127,7 +146,7 @@ sex_t	g_sex_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ǽͤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -216,7 +235,7 @@ abl_kind_t	g_abl_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ⤭ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -237,7 +256,7 @@ move_kind_t	g_move_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -296,7 +315,7 @@ act_kind_t	g_act_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * åȤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -322,7 +341,7 @@ trgt_kind_t	g_trgt_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ֹ礤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -340,7 +359,7 @@ dist_t	g_dist_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ֹ礤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -362,7 +381,7 @@ auto_mark_trgt_t	g_am_trgt_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ֹ礤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -380,7 +399,7 @@ auto_mark_dist_t	g_am_dist_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ֹ礤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -407,7 +426,7 @@ auto_mark_act_t	g_am_act_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ֹ礤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -451,7 +470,7 @@ auto_mark_cond_t	g_am_cond_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ⤭ǡμɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -471,7 +490,7 @@ move_ls_kind_t	g_move_ls_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ١ȿɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -494,7 +513,7 @@ attitude_t	g_attitude_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ƥɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -529,7 +548,7 @@ item_kind_t	g_item_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -646,7 +665,7 @@ wpn_kind_t	g_wpn_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ݤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -667,7 +686,7 @@ bow_kind_t	g_bow_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɶɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -734,7 +753,7 @@ armor_kind_t	g_armor_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 *  RAF ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -754,7 +773,7 @@ wpn_randm_art_kind_t	g_wpn_randm_art_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 *  RAF ɶɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -774,7 +793,7 @@ armor_randm_art_kind_t	g_armor_randm_art_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -859,7 +878,7 @@ potion_kind_t	g_potion_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ʪɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -900,7 +919,7 @@ scroll_kind_t	g_scroll_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -919,7 +938,7 @@ stick_kind_t	g_stick_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -938,7 +957,7 @@ acce_kind_t	g_acce_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ؤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -973,7 +992,7 @@ ring_kind_t	g_ring_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1005,7 +1024,7 @@ amulet_kind_t	g_amulet_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ؤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1035,7 +1054,7 @@ necklace_kind_t	g_necklace_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ڴɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1091,7 +1110,7 @@ inst_kind_t	g_inst_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1111,7 +1130,7 @@ anthology_kind_t	g_anthology_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1130,7 +1149,7 @@ light_kind_t	g_light_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ƥɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1152,7 +1171,7 @@ star_drop_kind_t	g_key_item_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ˾ߤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1172,7 +1191,7 @@ wish_level_t	g_wish_level_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1225,7 +1244,7 @@ food_kind_t	g_food_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1247,7 +1266,7 @@ tobacco_kind_t	g_tobacco_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * Υ֥ɤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1329,7 +1348,7 @@ tobacco_brand_t	g_tobacco_brand_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ѥפɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1348,7 +1367,7 @@ pipe_kind_t	g_pipe_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * õƥɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1375,7 +1394,7 @@ rare_goods_kind_t	g_rare_goods_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1394,7 +1413,7 @@ coin_kind_t	g_coin_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ˡɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1611,7 +1630,7 @@ spell_kind_t	g_spell_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * 󥹥ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1785,7 +1804,7 @@ mnstr_kind_t	g_mnstr_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * 櫤ɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1810,7 +1829,7 @@ trap_kind_t	g_trap_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * եȤɬơ֥ɲäơ
 * ֡եΥСѤ롣
@@ -1885,7 +1904,7 @@ fx_kind_t	g_fx_trans_tab[] = {
 * ֡ǡ򥻡֡ɤ
 * ߴݻ뤿Ѵơ֥롣
 * 
-* Ф˽֤ѹʤͤ
+*  Ф˽֤ѹʤͤˡ 
 * 
 * ɬơ֥ɲäơ
 * ֡եΥСѤ롣
