@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.64 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: gmain.h,v 1.68 2009/05/31 07:23:45 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -113,9 +113,11 @@
 
 #include	"misc.h"
 #include	"turn.h"
-
 #include	"msg-t.h"
 
+#include	"music-kind.h"
+#include	"sound-kind.h"
+
 /***************************************************************
 * 
 ***************************************************************/
@@ -148,9 +150,21 @@ EXTERN bool_t	g_flg_cui;
 /* GUI ⡼ */
 EXTERN bool_t	g_flg_gui;
 
-/* ɥޥ͡㤬 GNOME? */
+/* ɥɸ򥪥ץǻꤵ줿? */
+EXTERN bool_t	g_flg_win_pos_arg_overwrite;
+
+/* ɥޥ͡㤬 GNOME 򥪥ץǻꤵ줿? */
+EXTERN bool_t	g_flg_gnome_arg;
+
+/* ɥޥ͡㤬 GNOME ? */
 EXTERN bool_t	g_flg_gnome;
 
+/* ɥɽ˰֤ꤹ뤫򥪥ץǻꤵ줿? */
+EXTERN bool_t	g_flg_set_win_pos_arg;
+
+/* ɥɽ˰֤ꤹ뤫? */
+EXTERN bool_t	g_flg_set_win_pos;
+
 /* GUI Υƥɽ⡼ */
 EXTERN bool_t	g_flg_text_mode;
 
