@@ -68,6 +68,11 @@ void	move_crsr_abs( long x, long y );
 void	move_crsr_rel( long dx, long dy );
 char	*cb_menu_crsr_quick_move( menu_t **pp, menu_t **dflt );
 void	jump_crsr( long dx, long dy );
+char	*cb_menu_crsr_ind_square( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_ind_square_num( menu_t **pp, menu_t **dflt );
+char	*cb_menu_crsr_ind_square_mbr( menu_t **pp, menu_t **dflt );
+void	menu_crsr_ind_square_set_mbr( long mbr_n );
+char	*cb_menu_crsr_ind_square_party( menu_t **pp, menu_t **dflt );
 char	*cb_menu_crsr_scroll( menu_t **pp, menu_t **dflt );
 void	crsr_scroll( long dx, long dy );
 char	*cb_menu_crsr_move_mbr( menu_t **pp, menu_t **dflt );
@@ -99,7 +104,9 @@ bool_t	next_pos_square( long d );
 bool_t	next_pos_all( long d );
 bool_t	prev_pos( void );
 char	*cb_menu_back_log( menu_t **pp, menu_t **dflt );
+char	*exec_back_log( void );
 char	*cb_menu_ls_msg( menu_t **pp, menu_t **dflt );
+char	*cb_menu_ls_key_item( menu_t **pp, menu_t **dflt );
 char	*cb_menu_ls_mnstr( menu_t **pp, menu_t **dflt );
 char	*cb_menu_cnf( menu_t **pp, menu_t **dflt );
 char	*cb_menu_mbr_flg( menu_t **pp, menu_t **dflt );
@@ -160,6 +167,7 @@ char	*cb_menu_func( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_exec( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_edit( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_set_reg_macro( menu_t **pp, menu_t **dflt );
+char	*cb_menu_replay_music( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_n_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_kind_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_joystick_sel_n( menu_t **pp, menu_t **dflt );
@@ -214,6 +222,7 @@ bool_t	*get_ls_flg_srch( void );
 menu_t	*get_ls_menu_move_crsr( void );
 flg_scroll_t	get_flg_scroll( void );
 flg_scroll_t	set_flg_scroll( flg_scroll_t flg );
+bool_t	get_flg_mbr_data_change_page_is_crsr( void );
 
 #ifdef __cplusplus
 }
