@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.136 2009/05/12 04:08:02 bowkenken Exp $
+* $Id: inc.h,v 1.140 2009/05/31 08:05:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -92,6 +92,8 @@
 /*#include	"gfile-prot.h"*/
 #include	"msg-prot.h"
 
+#include	"call-prot.h"
+
 #endif	/* AMENU_C */
 
 /***************************************************************/
@@ -156,7 +158,6 @@
 #include	"last-boss.h"
 #include	"last-boss-prot.h"
 
-#include	"sound-kind.h"
 #include	"win-kind.h"
 #include	"call-prot.h"
 
@@ -420,7 +421,6 @@
 #include	"msg-prot.h"
 
 #include	"vfx-kind.h"
-#include	"sound-kind.h"
 #include	"win-kind.h"
 #include	"call-prot.h"
 
@@ -629,6 +629,8 @@
 #include	"last-boss.h"
 #include	"last-boss-prot.h"
 
+#include	"call-prot.h"
+
 #endif	/* FIGHT_C */
 
 /***************************************************************/
@@ -690,6 +692,8 @@
 /*#include	"gfile-prot.h"*/
 #include	"msg-prot.h"
 
+#include	"call-prot.h"
+
 #endif	/* FX_C */
 
 /***************************************************************/
@@ -1451,6 +1455,8 @@
 #include	"last-boss.h"
 #include	"last-boss-prot.h"
 
+#include	"call-prot.h"
+
 #endif	/* MNSTR_C */
 
 /***************************************************************/
@@ -1458,7 +1464,7 @@
 #ifdef	MSG_C
 
 #include	"gmain.h"
-/*#include	"misc.h"*/
+#include	"misc.h"
 /*#include	"scene.h"*/
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
@@ -1484,7 +1490,7 @@
 #include	"msg.h"
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
-/*#include	"misc-prot.h"*/
+#include	"misc-prot.h"
 /*#include	"scene-prot.h"*/
 /*#include	"turn-prot.h"*/
 /*#include	"dun-prot.h"*/
@@ -1639,6 +1645,8 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"call-prot.h"
+
 #endif	/* PET_C */
 
 /***************************************************************/
@@ -1700,6 +1708,8 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"call-prot.h"
+
 #endif	/* REQUEST_C */
 
 /***************************************************************/
@@ -1764,6 +1774,8 @@
 #include	"last-boss.h"
 #include	"last-boss-prot.h"
 
+#include	"call-prot.h"
+
 #endif	/* SPELL_C */
 
 /***************************************************************/
@@ -1825,8 +1837,6 @@
 #include	"gfile-prot.h"
 /*#include	"msg-prot.h"*/
 
-#include	"music-kind.h"
-#include	"sound-kind.h"
 #include	"call-prot.h"
 
 #endif	/* TMENU_C */
@@ -1951,6 +1961,8 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"call-prot.h"
+
 #endif	/* TRAP_C */
 
 /***************************************************************/
@@ -2140,6 +2152,7 @@
 #include	"key-item-prot.h"
 #include	"last-boss.h"
 #include	"last-boss-prot.h"
+#include	"call-prot.h"
 
 #endif	/* KEY_ITEM_C */
 
@@ -4186,7 +4199,7 @@
 /*#include	"amenu.h"*/
 /*#include	"request.h"*/
 /*#include	"gfile.h"*/
-/*#include	"msg.h"*/
+#include	"msg.h"
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
@@ -4215,7 +4228,7 @@
 /*#include	"amenu-prot.h"*/
 /*#include	"request-prot.h"*/
 /*#include	"gfile-prot.h"*/
-/*#include	"msg-prot.h"*/
+#include	"msg-prot.h"
 
 #ifdef D_WS
 #endif /* D_WS */
@@ -4302,6 +4315,163 @@
 
 /***************************************************************/
 
+#ifdef	MOUSE_MOTION_CPP
+
+#include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"map-event.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"skill.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+/*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"map-event-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#include "MouseMotion.h"
+#include "GlobalVar.h"
+
+#endif	/* MOUSE_MOTION_CPP */
+
+/***************************************************************/
+
+#ifdef	MOUSE_MAP_CPP
+
+#include	"gmain.h"
+/*#include	"misc.h"*/
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"map-event.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+#include	"chr.h"
+/*#include	"skill.h"*/
+#include	"party.h"
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"replay.h"
+#include	"draw.h"
+/*#include	"curs.h"*/
+#include	"menu.h"
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+/*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"map-event-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+#include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
+#include	"party-prot.h"
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+#include	"replay-prot.h"
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+#include	"menu-prot.h"
+#include	"mmenu-prot.h"
+#include	"imenu-prot.h"
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_WS
+# include <WScom.h>
+# include <WSCfunctionList.h>
+# include <WSCbase.h>
+
+# include <WSCvscrBar.h>
+# include <WSCwindow.h>
+#endif // D_WS
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+#endif // D_GTK
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+# include "xlnl-dows/MainFrm.h"
+#endif // D_MFC
+
+#include "GraphConf.h"
+#include "MouseMap.h"
+#include "Key.h"
+#include "GlobalVar.h"
+
+#ifdef D_GTK
+# include "main-gtk-prot.h"
+#endif // D_GTK
+
+#ifdef D_MFC
+# include "main-dows-prot.h"
+#endif // D_MFC
+
+#endif	/* MOUSE_MAP_CPP */
+
+/***************************************************************/
+
 #if 0
 #if	defined( D_WS )
 # include	"main-ws-prot.h"
