@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dows.cpp,v 1.30 2009/02/09 08:08:09 bowkenken Exp $
+* $Id: main-dows.cpp,v 1.31 2009/06/03 19:25:22 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -75,7 +75,7 @@ int	main_dows( int argc, char **argv )
 	}
 
 	init_game();
-	change_scene( SCENE_N_INIT );
+	change_scene_gui( SCENE_N_INIT );
 
 	theApp.InitWin();
 
@@ -92,7 +92,7 @@ int	main_dows( int argc, char **argv )
 		// ȥ
 
 		gPcgDun.initTitle();
-		change_scene( SCENE_N_TITLE );
+		change_scene_gui( SCENE_N_TITLE );
 		gPcgDun.drawTitle();
 
 		// եå
@@ -114,7 +114,7 @@ void	init_main_sel_conf( void *cnf )
 
 	gPcgDun.init( (GraphConf *)cnf );
 
-	change_scene( SCENE_N_TOWN );
+	change_scene_gui( SCENE_N_TOWN );
 
 	gGuiMenu.init();
 	gGuiMessage.init();
