@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.63 2009/05/13 23:37:14 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.65 2009/06/03 19:25:22 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -88,7 +88,7 @@ int	main( int argc, char **argv )
 
 	chk_arg( argc, argv );
 	init_game();
-	change_scene( SCENE_N_INIT );
+	change_scene_gui( SCENE_N_INIT );
 
 	if( g_flg_gui ){
 		init_gtk_win( argc, argv );
@@ -104,6 +104,14 @@ int	main( int argc, char **argv )
 
 		gtk_exit( EXIT_SUCCESS );
 	} else {
+		// SDL 
+
+		gMusic.init();
+		gSound.init();
+		gJoystick.init();
+
+		change_scene_gui( SCENE_N_TITLE );
+
 		// CUI Υᥤ󡦥롼פ򳫻
 
 		game_main();
@@ -148,7 +156,7 @@ void	init_gtk_win( int argc, char **argv )
 	// ȥ
 
 	gPcgDun.initTitle();
-	change_scene( SCENE_N_TITLE );
+	change_scene_gui( SCENE_N_TITLE );
 	gPcgDun.drawTitle();
 
 	// եå
@@ -179,7 +187,7 @@ void	init_main_sel_conf( GraphConf *cnf )
 	gPcgDun.init( cnf );
 	configure_map();
 
-	change_scene( SCENE_N_TOWN );
+	change_scene_gui( SCENE_N_TOWN );
 
 	gGuiMenu.init();
 	gGuiMessage.init();
