@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.228 2009/05/14 00:26:39 bowkenken Exp $
+* $Id: party.c,v 1.234 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -191,7 +191,7 @@ void	init_party( void )
 
 		str_nz_cpy( class_tab[j].name,
 				MSG( class_tab[j].n_name ),
-				CLASS_NAME_MAX_LEN );
+				CLASS_NAME_MAX_BYTE );
 	}
 
 	party.square.x = 1;
@@ -209,7 +209,7 @@ void	init_party( void )
 	party.square.chr_pos_n[2][0] = 4;
 	party.square.chr_pos_n[2][1] = MBR_NO_POS;
 	party.square.chr_pos_n[2][2] = 5;
-	set_mbr_dir();
+	reset_mbr_dir();
 
 	party.flg = FLG_NULL;
 	party.flg |= FLG_PARTY_SRCH_AUTO_OFF;
@@ -239,7 +239,7 @@ void	init_party_dflt( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_FIGHTER, 0 );
 	str_nz_cpy( ls_mbr[0]->graph_name, "mon_090.bmp",
@@ -247,7 +247,7 @@ void	init_party_dflt( void )
 
 	race.main = MAIN_RACE_DWARF;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[1], ")(==DRANK======>", 'D', race,
 			MALE, CLASS_N_FIGHTER, 1 );
 	str_nz_cpy( ls_mbr[1]->graph_name, "mon_194.bmp",
@@ -255,7 +255,7 @@ void	init_party_dflt( void )
 
 	race.main = MAIN_RACE_HALF_ELF;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, 2 );
 	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.bmp",
@@ -263,7 +263,7 @@ void	init_party_dflt( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, 3 );
 	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.bmp",
@@ -271,7 +271,7 @@ void	init_party_dflt( void )
 
 	race.main = MAIN_RACE_VIVID;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
 	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.bmp",
@@ -279,7 +279,7 @@ void	init_party_dflt( void )
 
 	race.main = MAIN_RACE_ELF;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, 5 );
 	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.bmp",
@@ -287,7 +287,7 @@ void	init_party_dflt( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_MONKEY;
-	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
 	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.bmp",
@@ -295,7 +295,7 @@ void	init_party_dflt( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_CAT;
-	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, 7 );
 	str_nz_cpy( ls_mbr[7]->graph_name, "mon_242.bmp",
@@ -455,7 +455,7 @@ void	init_party_debug( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_NINJA, 0 );
 	str_nz_cpy( ls_mbr[0]->graph_name, "mon_090.bmp",
@@ -463,7 +463,7 @@ void	init_party_debug( void )
 
 	race.main = MAIN_RACE_DWARF;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[1], ")(==DRANK======>", 'D', race,
 			MALE, CLASS_N_FIGHTER, 1 );
 	str_nz_cpy( ls_mbr[1]->graph_name, "mon_194.bmp",
@@ -471,7 +471,7 @@ void	init_party_debug( void )
 
 	race.main = MAIN_RACE_HALF_ELF;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, 2 );
 	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.bmp",
@@ -479,7 +479,7 @@ void	init_party_debug( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, 3 );
 	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.bmp",
@@ -487,7 +487,7 @@ void	init_party_debug( void )
 
 	race.main = MAIN_RACE_VIVID;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
 	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.bmp",
@@ -495,7 +495,7 @@ void	init_party_debug( void )
 
 	race.main = MAIN_RACE_ELF;
 	race.sub = SUB_RACE_NULL;
-	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, 5 );
 	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.bmp",
@@ -503,7 +503,7 @@ void	init_party_debug( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_MONKEY;
-	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
 	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.bmp",
@@ -511,7 +511,7 @@ void	init_party_debug( void )
 
 	race.main = MAIN_RACE_HUMAN;
 	race.sub = SUB_RACE_CAT;
-	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_LEN );
+	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[7], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, 7 );
 	str_nz_cpy( ls_mbr[7]->graph_name, "mon_242.bmp",
@@ -1215,7 +1215,7 @@ void	new_mbr(
 	mbr->sort_chr_next = NULL;
 
 	mbr->kind = CHR_KIND_MBR;
-	str_nz_cpy( mbr->name, name, MBR_NAME_MAX_LEN );
+	str_nz_cpy( mbr->name, name, MBR_NAME_MAX_BYTE );
 	mbr->mbr_n = MBR_N_NOT_JOIN;
 	mbr->ls_mbr_n = ls_mbr_n;
 	mbr->face.mjr = FACE_MJR_MBR;
@@ -1261,7 +1261,7 @@ void	new_mbr(
 	mbr->trgt.dflt_dist_mnstr = DIST_NEAR;
 	mbr->act.dflt_kind_mnstr = ACT_KIND_MNSTR_FIGHT;
 	str_nz_cpy( mbr->act.dflt_msg_mnstr,
-			MSG_MENU_MARK_FIGHT, ACT_MSG_MAX_LEN );
+			MSG_MENU_MARK_FIGHT, ACT_MSG_MAX_BYTE );
 	clr_chr_trgt_act( mbr, TRUE );
 	mbr->pre_act = mbr->act;
 
@@ -1407,54 +1407,57 @@ bool_t	reset_mbr_resi( mbr_t *mbr )
 
 /**/
 
-void	set_mbr_dir( void )
+void	reset_mbr_dir( void )
 {
+	square_t	*sq;
 	long	i, j;
 
-	switch( party.square.dir ){
+	sq = &(party.square);
+
+	switch( sq->dir ){
 	case SQUARE_DIR_NORTH:
-		party.square.chr_dir[0][0] = party.square.chr_pos_n[0][0];
-		party.square.chr_dir[0][1] = party.square.chr_pos_n[0][1];
-		party.square.chr_dir[0][2] = party.square.chr_pos_n[0][2];
-		party.square.chr_dir[1][0] = party.square.chr_pos_n[1][0];
-		party.square.chr_dir[1][1] = party.square.chr_pos_n[1][1];
-		party.square.chr_dir[1][2] = party.square.chr_pos_n[1][2];
-		party.square.chr_dir[2][0] = party.square.chr_pos_n[2][0];
-		party.square.chr_dir[2][1] = party.square.chr_pos_n[2][1];
-		party.square.chr_dir[2][2] = party.square.chr_pos_n[2][2];
+		sq->chr_dir[0][0] = sq->chr_pos_n[0][0];
+		sq->chr_dir[0][1] = sq->chr_pos_n[0][1];
+		sq->chr_dir[0][2] = sq->chr_pos_n[0][2];
+		sq->chr_dir[1][0] = sq->chr_pos_n[1][0];
+		sq->chr_dir[1][1] = sq->chr_pos_n[1][1];
+		sq->chr_dir[1][2] = sq->chr_pos_n[1][2];
+		sq->chr_dir[2][0] = sq->chr_pos_n[2][0];
+		sq->chr_dir[2][1] = sq->chr_pos_n[2][1];
+		sq->chr_dir[2][2] = sq->chr_pos_n[2][2];
 		break;
 	case SQUARE_DIR_EAST:
-		party.square.chr_dir[0][0] = party.square.chr_pos_n[2][0];
-		party.square.chr_dir[0][1] = party.square.chr_pos_n[1][0];
-		party.square.chr_dir[0][2] = party.square.chr_pos_n[0][0];
-		party.square.chr_dir[1][0] = party.square.chr_pos_n[2][1];
-		party.square.chr_dir[1][1] = party.square.chr_pos_n[1][1];
-		party.square.chr_dir[1][2] = party.square.chr_pos_n[0][1];
-		party.square.chr_dir[2][0] = party.square.chr_pos_n[2][2];
-		party.square.chr_dir[2][1] = party.square.chr_pos_n[1][2];
-		party.square.chr_dir[2][2] = party.square.chr_pos_n[0][2];
+		sq->chr_dir[0][0] = sq->chr_pos_n[2][0];
+		sq->chr_dir[0][1] = sq->chr_pos_n[1][0];
+		sq->chr_dir[0][2] = sq->chr_pos_n[0][0];
+		sq->chr_dir[1][0] = sq->chr_pos_n[2][1];
+		sq->chr_dir[1][1] = sq->chr_pos_n[1][1];
+		sq->chr_dir[1][2] = sq->chr_pos_n[0][1];
+		sq->chr_dir[2][0] = sq->chr_pos_n[2][2];
+		sq->chr_dir[2][1] = sq->chr_pos_n[1][2];
+		sq->chr_dir[2][2] = sq->chr_pos_n[0][2];
 		break;
 	case SQUARE_DIR_SOUTH:
-		party.square.chr_dir[0][0] = party.square.chr_pos_n[2][2];
-		party.square.chr_dir[0][1] = party.square.chr_pos_n[2][1];
-		party.square.chr_dir[0][2] = party.square.chr_pos_n[2][0];
-		party.square.chr_dir[1][0] = party.square.chr_pos_n[1][2];
-		party.square.chr_dir[1][1] = party.square.chr_pos_n[1][1];
-		party.square.chr_dir[1][2] = party.square.chr_pos_n[1][0];
-		party.square.chr_dir[2][0] = party.square.chr_pos_n[0][2];
-		party.square.chr_dir[2][1] = party.square.chr_pos_n[0][1];
-		party.square.chr_dir[2][2] = party.square.chr_pos_n[0][0];
+		sq->chr_dir[0][0] = sq->chr_pos_n[2][2];
+		sq->chr_dir[0][1] = sq->chr_pos_n[2][1];
+		sq->chr_dir[0][2] = sq->chr_pos_n[2][0];
+		sq->chr_dir[1][0] = sq->chr_pos_n[1][2];
+		sq->chr_dir[1][1] = sq->chr_pos_n[1][1];
+		sq->chr_dir[1][2] = sq->chr_pos_n[1][0];
+		sq->chr_dir[2][0] = sq->chr_pos_n[0][2];
+		sq->chr_dir[2][1] = sq->chr_pos_n[0][1];
+		sq->chr_dir[2][2] = sq->chr_pos_n[0][0];
 		break;
 	case SQUARE_DIR_WEST:
-		party.square.chr_dir[0][0] = party.square.chr_pos_n[0][2];
-		party.square.chr_dir[0][1] = party.square.chr_pos_n[1][2];
-		party.square.chr_dir[0][2] = party.square.chr_pos_n[2][2];
-		party.square.chr_dir[1][0] = party.square.chr_pos_n[0][1];
-		party.square.chr_dir[1][1] = party.square.chr_pos_n[1][1];
-		party.square.chr_dir[1][2] = party.square.chr_pos_n[2][1];
-		party.square.chr_dir[2][0] = party.square.chr_pos_n[0][0];
-		party.square.chr_dir[2][1] = party.square.chr_pos_n[1][0];
-		party.square.chr_dir[2][2] = party.square.chr_pos_n[2][0];
+		sq->chr_dir[0][0] = sq->chr_pos_n[0][2];
+		sq->chr_dir[0][1] = sq->chr_pos_n[1][2];
+		sq->chr_dir[0][2] = sq->chr_pos_n[2][2];
+		sq->chr_dir[1][0] = sq->chr_pos_n[0][1];
+		sq->chr_dir[1][1] = sq->chr_pos_n[1][1];
+		sq->chr_dir[1][2] = sq->chr_pos_n[2][1];
+		sq->chr_dir[2][0] = sq->chr_pos_n[0][0];
+		sq->chr_dir[2][1] = sq->chr_pos_n[1][0];
+		sq->chr_dir[2][2] = sq->chr_pos_n[2][0];
 		break;
 	case SQUARE_DIR_MAX_N:
 		break;
@@ -1463,16 +1466,136 @@ void	set_mbr_dir( void )
 	for( i = 0; i < SQUARE_HEIGHT; i++ ){
 		for( j = 0; j < SQUARE_WIDTH; j++ ){
 			long	n;
-			
-			n = party.square.chr_dir[i][j];
-			if( n != MBR_NO_POS ){
-				party.square.chr_pos[n].x = j - 1;
-				party.square.chr_pos[n].y = i - 1;
-			}
+			long	x, y;
+
+			n = sq->chr_dir[i][j];
+			if( n == MBR_NO_POS )
+				continue;
+
+			sq->chr_rel_pos[n].x = j - 1;
+			sq->chr_rel_pos[n].y = i - 1;
+
+			x = sq->x + sq->chr_rel_pos[n].x;
+			y = sq->y + sq->chr_rel_pos[n].y;
+
+			sq->chr_abs_pos[n].x = x;
+			sq->chr_abs_pos[n].y = y;
+
+			sq->chr_ind_pos[n].x = x;
+			sq->chr_ind_pos[n].y = y;
+
+			sq->chr_map_pos[n].x = x;
+			sq->chr_map_pos[n].y = y;
 		}
 	}
 }
 
+/***************************************************************
+* ƥСθ̤Υ󥫡ɸꥻåȤ
+***************************************************************/
+
+void	reset_square_mbr_ind_pos( void )
+{
+	long	n;
+
+	for( n = 0; n < MBR_MAX_N; n++ ){
+		party.square.chr_ind_pos[n].x
+				= party.square.chr_abs_pos[n].x;
+		party.square.chr_ind_pos[n].y
+				= party.square.chr_abs_pos[n].y;
+	}
+}
+
+/***************************************************************
+* Сθ̤Υ󥫡ɸꤹ
+***************************************************************/
+
+void	set_square_mbr_ind_pos( long mbr_n, long x, long y )
+{
+	square_t	*sq;
+
+	if( mbr_n < 0 )
+		return;
+	if( mbr_n >= MBR_MAX_N )
+		return;
+
+	sq = &(party.square);
+
+	sq->chr_ind_pos[mbr_n].x = x;
+	sq->chr_ind_pos[mbr_n].y = y;
+
+	sq->chr_map_pos[mbr_n].x = x;
+	sq->chr_map_pos[mbr_n].y = y;
+}
+
+/***************************************************************
+* 饯Υޥå׾кɸ (Υ󥫡) ֤
+***************************************************************/
+
+void	get_square_mbr_abs_pos( long mbr_n, long *x, long *y )
+{
+	square_t	*sq;
+
+	if( x != NULL )
+		*x = 0;
+	if( y != NULL )
+		*y = 0;
+
+	if( mbr_n < 0 )
+		return;
+	if( mbr_n >= MBR_MAX_N )
+		return;
+
+	sq = &(party.square);
+
+	sq->chr_abs_pos[mbr_n].x = sq->x + sq->chr_rel_pos[mbr_n].x;
+	sq->chr_abs_pos[mbr_n].y = sq->y + sq->chr_rel_pos[mbr_n].y;
+
+	if( x != NULL )
+		*x = sq->chr_abs_pos[mbr_n].x;
+	if( y != NULL )
+		*y = sq->chr_abs_pos[mbr_n].y;
+}
+
+/***************************************************************
+* ƥСΥ󥫡ɸ֤
+***************************************************************/
+
+void	get_square_mbr_map_pos( long mbr_n, long *x, long *y )
+{
+	if( x != NULL )
+		*x = 0;
+	if( y != NULL )
+		*y = 0;
+
+	if( mbr_n < 0 )
+		return;
+	if( mbr_n >= MBR_MAX_N )
+		return;
+
+	if( x != NULL )
+		*x = party.square.chr_map_pos[mbr_n].x;
+	if( y != NULL )
+		*y = party.square.chr_map_pos[mbr_n].y;
+}
+
+/***************************************************************
+* µܤȳȽ̤ƥСޥåפ˽и
+***************************************************************/
+
+void	appear_party_auto( void )
+{
+	dun_t	*dun;
+
+	dun = get_dun();
+
+	if( dun->lev == 0 ){
+		appear_party_town();
+	} else {
+		appear_party();
+	}
+}
+
 /***************************************************************
 * Сޥåפ˽и
 ***************************************************************/
@@ -1519,13 +1642,18 @@ void	appear_party( void )
 
 bool_t	appear_party_randm( void )
 {
+	square_t	*sq;
 	long	i, n;
 
+	sq = get_square_mbr();
+	if( sq == NULL )
+		return FALSE;
+
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
-		party.square.x = 1 + randm( MAP_MAX_X - 2);
-		party.square.y = 1 + randm( MAP_MAX_Y - 2);
-		party.square.pre_x = party.square.x;
-		party.square.pre_y = party.square.y;
+		sq->x = 1 + randm( MAP_MAX_X - 2);
+		sq->y = 1 + randm( MAP_MAX_Y - 2);
+		sq->pre_x = sq->x;
+		sq->pre_y = sq->y;
 
 		for( n = 0; n < MBR_MAX_N; n++ ){
 			long	nx, ny;
@@ -1536,8 +1664,7 @@ bool_t	appear_party_randm( void )
 				continue;
 			}
 
-			nx = party.square.x + party.square.chr_pos[n].x;
-			ny = party.square.y + party.square.chr_pos[n].y;
+			get_square_mbr_abs_pos( n, &nx, &ny );
 			party.mbr[n]->x = nx;
 			party.mbr[n]->y = ny;
 			party.mbr[n]->pre_x = nx;
@@ -1550,11 +1677,13 @@ bool_t	appear_party_randm( void )
 		}
 		if( n >= MBR_MAX_N ){
 			/* ư褿 */
+			reset_mbr_dir();
 			return TRUE;
 		}
 	}
 
 	/* ưʤä */
+	reset_mbr_dir();
 	return FALSE;
 }
 
@@ -1565,11 +1694,16 @@ bool_t	appear_party_randm( void )
 
 bool_t	appear_party_srch( void )
 {
+	square_t	*sq;
 	long	randm_x, randm_y;
 	long	xx, yy;
 	long	x, y;
 	long	n;
 
+	sq = get_square_mbr();
+	if( sq == NULL )
+		return FALSE;
+
 	randm_x = randm( MAP_MAX_X );
 	randm_y = randm( MAP_MAX_Y );
 
@@ -1586,10 +1720,10 @@ bool_t	appear_party_srch( void )
 			if( y >= MAP_MAX_Y - 1 )
 				continue;
 
-			party.square.x = x;
-			party.square.y = y;
-			party.square.pre_x = party.square.x;
-			party.square.pre_y = party.square.y;
+			sq->x = x;
+			sq->y = y;
+			sq->pre_x = sq->x;
+			sq->pre_y = sq->y;
 
 			for( n = 0; n < MBR_MAX_N; n++ ){
 				long	nx, ny;
@@ -1600,10 +1734,7 @@ bool_t	appear_party_srch( void )
 					continue;
 				}
 
-				nx = party.square.x;
-				ny = party.square.y;
-				nx += party.square.chr_pos[n].x;
-				ny += party.square.chr_pos[n].y;
+				get_square_mbr_abs_pos( n, &nx, &ny );
 				party.mbr[n]->x = nx;
 				party.mbr[n]->y = ny;
 				party.mbr[n]->pre_x = nx;
@@ -1616,12 +1747,14 @@ bool_t	appear_party_srch( void )
 			}
 			if( n >= MBR_MAX_N ){
 				/* ư褿 */
+				reset_mbr_dir();
 				return TRUE;
 			}
 		}
 	}
 
 	/* ưʤä */
+	reset_mbr_dir();
 	return FALSE;
 }
 
@@ -1651,6 +1784,8 @@ void	appear_party_force( void )
 
 		put_chr( party.mbr[n], x, y );
 	}
+
+	reset_mbr_dir();
 }
 
 /***************************************************************
@@ -1669,10 +1804,15 @@ void	appear_party_last_boss( void )
 
 void	appear_party_map_event( char mnr )
 {
+	square_t	*sq;
 	pos_t	pos;
 	long	x, y;
 	long	n;
 
+	sq = get_square_mbr();
+	if( sq == NULL )
+		return;
+
 	for( n = 0; n < MBR_MAX_N; n++ ){
 		lost_trgt( party.mbr[n] );
 		clr_chr_trgt_act( party.mbr[n], FALSE );
@@ -1685,10 +1825,10 @@ void	appear_party_map_event( char mnr )
 	x = pos.x;
 	y = pos.y;
 
-	party.square.x = x;
-	party.square.y = y;
-	party.square.pre_x = party.square.x;
-	party.square.pre_y = party.square.y;
+	sq->x = x;
+	sq->y = y;
+	sq->pre_x = sq->x;
+	sq->pre_y = sq->y;
 
 	for( n = 0; n < MBR_MAX_N; n++ ){
 		long	nx, ny;
@@ -1699,8 +1839,7 @@ void	appear_party_map_event( char mnr )
 			continue;
 		}
 
-		nx = party.square.x + party.square.chr_pos[n].x;
-		ny = party.square.y + party.square.chr_pos[n].y;
+		get_square_mbr_abs_pos( n, &nx, &ny );
 
 		party.mbr[n]->x = MAP_DEL_X;
 		party.mbr[n]->y = MAP_DEL_Y;
@@ -1708,6 +1847,7 @@ void	appear_party_map_event( char mnr )
 		put_chr( party.mbr[n], nx, ny );
 	}
 
+	reset_mbr_dir();
 	appear_all_pet();
 
 	next_pos_square( 0 );
@@ -1976,6 +2116,8 @@ void	die_mbr( mbr_t *mbr, bool_t flg_chk_game_over )
 	if( !is_mbr( mbr ) )
 		return;
 
+	call_game_sound_play( SOUND_KIND_FIGHT_DIE_MEMBER, 1 );
+
 	if( !flg_chk_game_over )
 		return;
 
@@ -2099,8 +2241,7 @@ void	join_mbr( long ls_mbr_n, long mbr_n )
 	party.mbr[mbr_n] = ls_mbr[ls_mbr_n];
 	ls_mbr[ls_mbr_n]->mbr_n = mbr_n;
 
-	x = party.square.x + party.square.chr_pos[mbr_n].x;
-	y = party.square.y + party.square.chr_pos[mbr_n].y;
+	get_square_mbr_map_pos( mbr_n, &x, &y );
 	put_chr( party.mbr[mbr_n], x, y );
 }
 
@@ -3054,10 +3195,10 @@ bool_t	chk_already_mark( void *p, mbr_t *mbr )
 
 char	*get_race_str( race_t *race )
 {
-	static char	str_main[RACE_STR_MAX_LEN + 1];
-	static char	str_sub[RACE_STR_MAX_LEN + 1];
-	static char	str_tmp[RACE_STR_MAX_LEN * 3 + 1];
-	static char	str_name[RACE_STR_MAX_LEN + 1];
+	static char	str_main[RACE_STR_MAX_BYTE + 1];
+	static char	str_sub[RACE_STR_MAX_BYTE + 1];
+	static char	str_tmp[RACE_STR_MAX_BYTE * 3 + 1];
+	static char	str_name[RACE_STR_MAX_BYTE + 1];
 
 	if( race == NULL )
 		return MSG_NULL;
@@ -3067,18 +3208,20 @@ char	*get_race_str( race_t *race )
 	str_tmp[0] = '\0';
 	str_name[0] = '\0';
 
-	str_nz_cpy( str_main, get_race_str_main( race ), RACE_STR_MAX_LEN );
-	str_nz_cpy( str_sub, get_race_str_sub( race ), RACE_STR_MAX_LEN );
+	str_nz_cpy( str_main, get_race_str_main( race ),
+			RACE_STR_MAX_BYTE );
+	str_nz_cpy( str_sub, get_race_str_sub( race ),
+			RACE_STR_MAX_BYTE );
 
 	if( race->sub == SUB_RACE_NULL ){
-		sn_printf( str_tmp, RACE_STR_MAX_LEN,
+		sn_printf( str_tmp, RACE_STR_MAX_BYTE,
 				MSG_RACE_STR_PUREBRED, str_main );
 	} else {
-		sn_printf( str_tmp, RACE_STR_MAX_LEN,
+		sn_printf( str_tmp, RACE_STR_MAX_BYTE,
 				MSG_RACE_STR_MIXED, str_main, str_sub );
 	}
 
-	str_nz_cpy( str_name, str_tmp, RACE_STR_MAX_LEN );
+	str_nz_cpy( str_name, str_tmp, RACE_STR_MAX_BYTE );
 
 	return str_name;
 }
@@ -3325,7 +3468,7 @@ bool_t	cmp_class( class_t *org, class_t *dst )
 	long	abl;
 	long	i;
 
-	if( strncmp( org->name, dst->name, CLASS_NAME_MAX_LEN ) != 0 )
+	if( strncmp( org->name, dst->name, CLASS_NAME_MAX_BYTE ) != 0 )
 		return FALSE;
 
 	for( abl = 0; abl < ABL_KIND_MAX_N; abl++ )
@@ -3427,23 +3570,43 @@ void	set_square_mbr( square_t *sq )
 
 /**/
 
-void	get_square_pos( long *x, long *y )
+void	get_square_pos( long *x, long *y, bool_t flg_pre )
 {
-	if( x != NULL )
-		*x = party.square.x;
-	if( y != NULL )
-		*y = party.square.y;
+	if( x != NULL ){
+		if( flg_pre ){
+			*x = party.square.pre_x;
+		} else {
+			*x = party.square.x;
+		}
+	}
+	if( y != NULL ){
+		if( flg_pre ){
+			*y = party.square.pre_y;
+		} else {
+			*y = party.square.y;
+		}
+	}
 }
 
 /**/
 
-void	set_square_pos( long x, long y )
+void	set_square_pos( long x, long y, bool_t flg_pre )
 {
 	if( !clip_pos( x, y ) )
 		return;
 
-	party.square.x = x;
-	party.square.y = y;
+	if( flg_pre ){
+		party.square.pre_x = x;
+		party.square.pre_y = y;
+	} else {
+		party.square.pre_x = party.square.x;
+		party.square.pre_y = party.square.y;
+
+		party.square.x = x;
+		party.square.y = y;
+	}
+
+	reset_mbr_dir();
 }
 
 /**/
@@ -3457,7 +3620,7 @@ void	unset_square_pos( void )
 	party.square.y = party.square.pre_y;
 	party.square.dir = party.square.pre_dir;
 
-	set_mbr_dir();
+	reset_mbr_dir();
 }
 
 /**/
