@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.75 2009/01/31 01:40:40 bowkenken Exp $
+* $Id: trap.c,v 1.78 2009/06/01 13:47:35 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -535,14 +535,17 @@ void	chk_trap_chest( item_t *chest, chr_t *chr, rate_t rate )
 	if( chest->kind != ITEM_KIND_CHEST )
 		return;
 
-	if( !rate_randm( rate ) )
+	if( !rate_randm( rate ) ){
+		call_game_sound_play( SOUND_KIND_TRAP_SAFE, 1 );
 		return;
+	}
 
 	flg_free = TRUE;
 	if( chest->dat.chest.trap != NULL )
 		if( chest->dat.chest.trap->kind == TRAP_KIND_CHUTE )
 			flg_free = FALSE;
 
+	call_game_sound_play( SOUND_KIND_TRAP_CAUGHT, 1 );
 	caught_trap( chest->dat.chest.trap, chr );
 
 	if( flg_free )
@@ -594,6 +597,9 @@ void	chk_trap( chr_t *chr, chr_t *thief )
 
 	if( chr_roll( thief, ABL_KIND_THI, ABL_KIND_AGI,
 			trap->difficulty ) ){
+		if( is_mbr( chr ) || is_pet( chr ) )
+			call_game_sound_play( SOUND_KIND_TRAP_SAFE, 1 );
+
 		curs_attrset_chr( chr, +1, FALSE );
 		print_msg_mbr( chr, FLG_NULL, MSG_NOT_TRAPPED, chr->name );
 		curs_attrset_dflt();
@@ -642,6 +648,9 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 	if( chk_flg_or( chr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 		return;
 
+	if( is_mbr( chr ) || is_pet( chr ) )
+		call_game_sound_play( SOUND_KIND_TRAP_CAUGHT, 1 );
+
 	if( is_mbr( chr ) ){
 		find_trap( trap );
 	} else {
@@ -657,7 +666,7 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 	}
 
 	g_dmy_chr.kind = CHR_KIND_NULL;
-	str_nz_cpy( g_dmy_chr.name, trap->tab->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( g_dmy_chr.name, trap->tab->name, CHR_NAME_MAX_BYTE );
 	g_dmy_chr.x = trap->x;
 	g_dmy_chr.y = trap->y;
 	g_dmy_chr.trgt.kind = get_trgt_kind_from_chr( chr );
@@ -830,6 +839,8 @@ void	disarm_trap( trap_t *p )
 	if( p == NULL )
 		return;
 
+	call_game_sound_play( SOUND_KIND_TRAP_DISARM, 1 );
+
 	dun = get_dun();
 
 	dun->map.obj.mjr[p->y][p->x] = FACE_MJR_FLOOR;
